==> longship-2023.6.27.tar.gz: longship-2023.6.27/longship_api_client/models/location_charge_point_dto.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="LocationChargePointDto")


@attr.s(auto_attribs=True)
class LocationChargePointDto:
    """
    Attributes:
        charge_point_id (Union[Unset, str]):
    """

    charge_point_id: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        charge_point_id = self.charge_point_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if charge_point_id is not UNSET:
            field_dict["chargePointId"] = charge_point_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        charge_point_id = d.pop("chargePointId", UNSET)

        location_charge_point_dto = cls(
            charge_point_id=charge_point_id,
        )

        location_charge_point_dto.additional_properties = d
        return location_charge_point_dto

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> longship-2024.4.17.tar.gz: longship-2024.4.17/longship_api_client/models/location_charge_point_dto.py <==
from typing import Any, Dict, Type, TypeVar

from typing import List


from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Union


T = TypeVar("T", bound="LocationChargePointDto")


@_attrs_define
class LocationChargePointDto:
    """
    Attributes:
        charge_point_id (Union[Unset, str]):
    """

    charge_point_id: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        charge_point_id = self.charge_point_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if charge_point_id is not UNSET:
            field_dict["chargePointId"] = charge_point_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        charge_point_id = d.pop("chargePointId", UNSET)

        location_charge_point_dto = cls(
            charge_point_id=charge_point_id,
        )

        location_charge_point_dto.additional_properties = d
        return location_charge_point_dto

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
